CookieBackend

Struct CookieBackend 

pub struct CookieBackend { /* private fields */ }
A Backend using a Cookie entry for storing the session data.

Implementations

Source

impl CookieBackend

pub fn plain() -> Self

Create a new CookieBackend that save uses the plain format.

pub fn signed(secret_key: Key) -> Self

Create a new CookieBackend that signs the cookie entry with the specified Key.

pub fn private(secret_key: Key) -> Self

Create a new CookieBackend that encrypts the cookie entry with the specified Key.

pub fn cookie_name(self, value: impl Into<Cow<'static, str>>) -> Self

Sets the name of Cookie entry to be used for storing the session data.

The default value is "tsukuyomi-session".

pub fn builder( self, builder: impl Fn(CookieBuilder) -> CookieBuilder + Send + Sync + 'static, ) -> Self

Sets the functions for modifying the saved Cookie entry.