Session

Struct Session 

pub struct Session<S: RawSession> { /* private fields */ }
An interface of session values.

Implementations

Source

impl<S> Session<S>
where S: RawSession,

pub fn get<T>(&self, name: &str) -> Result<Option<T>>

Retrieves a field from this session and parses it into the specified type.

pub fn contains(&self, name: &str) -> bool

Returns true if the field of specified name exists in this session.

pub fn set<T>(&mut self, name: &str, value: T) -> Result<()>
where T: Serialize,

Sets a field to this session with serializing the specified value into a string.

pub fn remove(&mut self, name: &str)

Removes a field from this session.

pub fn clear(&mut self)

Marks this session cleared.

pub fn finish<T>( self, output: T, ) -> impl Responder<Response = T::Response, Error = Error, Respond = SessionRespond<S::WriteSession, T::Respond>>
where T: Responder,

Finalize the current session with the specified output.