pub struct CookieBackend { /* private fields */ }Expand description
A Backend using a Cookie entry for storing the session data.
Implementations
Sourceimpl CookieBackend
impl CookieBackend
Sourcepub fn signed(secret_key: Key) -> Self
pub fn signed(secret_key: Key) -> Self
Create a new CookieBackend that signs the cookie entry with the specified Key.
Sourcepub fn private(secret_key: Key) -> Self
pub fn private(secret_key: Key) -> Self
Create a new CookieBackend that encrypts the cookie entry with the specified Key.
Sets the name of Cookie entry to be used for storing the session data.
The default value is "tsukuyomi-session".
Sourcepub fn builder(
self,
builder: impl Fn(CookieBuilder) -> CookieBuilder + Send + Sync + 'static,
) -> Self
pub fn builder( self, builder: impl Fn(CookieBuilder) -> CookieBuilder + Send + Sync + 'static, ) -> Self
Sets the functions for modifying the saved Cookie entry.